package ru.pricepulse.parsingservice.ozon_parser.service.marketplace.ozon.parsing;

import java.util.ArrayList;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.atomic.AtomicBoolean;

import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import ru.pricepulse.parsingservice.ozon_parser.service.MarketplaceParsingService;

@Slf4j
@Service
public class ParsingService implements MarketplaceParsingService {

    private final AtomicBoolean stopFlag = new AtomicBoolean(false);

    private final ExecutorService categoryExecutor = Executors.newFixedThreadPool(1);

    private final CategoryPageParsingService categoryPageParsingService;

    public ParsingService(CategoryPageParsingService categoryPageParsingService) {
        this.categoryPageParsingService = categoryPageParsingService;
    }

    public void processCategory(String url) {
        var startTime = System.currentTimeMillis();
        log.info("Начало обработки категории: {}", url);
        int pageIndex = 1;
        var errors = new ArrayList<String>();

        while (!stopFlag.get()) {
            int finalPageIndex = pageIndex;
            try {
                categoryPageParsingService.parseCategoryPage(finalPageIndex, url, errors);
            } catch (InterruptedException e) {
                throw new RuntimeException(e);
            }
            ++pageIndex;
            if (pageIndex > 5) {
                stopFlag.set(true);
            }
        }
        log.info("Время выполнения {} ", (System.currentTimeMillis() - startTime) / 1000);
    }

}